import React, { useState, useEffect } from 'react';
import { Computer, MessageSquare, History, Plus } from 'lucide-react';
import { TicketForm } from './components/TicketForm';
import { TicketHistory } from './components/TicketHistory';
import { ChatInterface } from './components/ChatInterface';
import { TicketConfirmation } from './components/TicketConfirmation';
import { apiService } from './services/apiService';
import { Ticket } from './types';
import { FilePlus } from 'lucide-react'; // Add this import at the top


function App() {
  const [activeTab, setActiveTab] = useState<'new' | 'history' | 'chat'>('new');
  const [tickets, setTickets] = useState<Ticket[]>([]);
  const [showConfirmation, setShowConfirmation] = useState<Ticket | null>(null);
  const [isLoadingTickets, setIsLoadingTickets] = useState(false);

  // Load tickets from backend on component mount
  useEffect(() => {
    loadTickets();
  }, []);

  const loadTickets = async () => {
    setIsLoadingTickets(true);
    try {
      const backendTickets = await apiService.getTickets();
      // Convert backend format to frontend format
      const formattedTickets: Ticket[] = backendTickets.map((ticket: any) => ({
        ...ticket,
        status: 'Open' as const, // Backend doesn't have status field yet
        timestamp: new Date(ticket.timestamp).toLocaleString()
      }));
      setTickets(formattedTickets);
    } catch (error) {
      console.error('Error loading tickets:', error);
    } finally {
      setIsLoadingTickets(false);
    }
  };

  const handleTicketSubmit = (ticket: Ticket) => {
    setTickets(prev => [ticket, ...prev]);
    setShowConfirmation(ticket);
  };

  const handleTicketUpdate = (ticketId: string, updates: Partial<Ticket>) => {
    setTickets(prev => 
      prev.map(ticket => 
        ticket.id === ticketId ? { ...ticket, ...updates } : ticket
      )
    );
  };

  const handleCreateTicketFromChat = (conversation: string) => {
    // This would typically show a form pre-filled with the conversation
    // For now, we'll just switch to the new ticket tab
    setActiveTab('new');
  };

  const tabs = [
    { id: 'new' as const, label: 'New Ticket', icon: Plus },
    { id: 'history' as const, label: 'History', icon: History },
    { id: 'chat' as const, label: 'Live Chat', icon: MessageSquare }
  ];

  return (
    <div className="min-h-screen bg-gray-950 text-white">
      {/* Header */}
      <div className="bg-gray-900 border-b border-gray-800">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="flex items-center justify-between h-16">
            <div className="flex items-center gap-3">
              <div className="w-10 h-10 bg-gradient-to-r from-blue-600 to-purple-600 rounded-lg flex items-center justify-center">
                <Computer className="w-6 h-6 text-white" />
              </div>
              <div>
                <h1 className="text-xl font-bold">DIGI TICKET</h1>
                <p className="text-xs text-gray-400">IT Support System</p>
              </div>
            </div>
            
            <div className="flex items-center gap-2 text-sm text-gray-400">
              <span>Total Tickets:</span>
              <span className="text-white font-semibold">
                {isLoadingTickets ? '...' : tickets.length}
              </span>
            </div>
          </div>
        </div>
      </div>

      {/* Navigation */}
      <div className="bg-gray-900 border-b border-gray-800">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <nav className="flex space-x-1">
            {tabs.map((tab) => {
              const Icon = tab.icon;
              return (
                <button
                  key={tab.id}
                  onClick={() => setActiveTab(tab.id)}
                  className={`flex items-center gap-2 px-6 py-4 text-sm font-medium transition-all duration-200 border-b-2 ${
                    activeTab === tab.id
                      ? 'text-blue-400 border-blue-400 bg-blue-400/5'
                      : 'text-gray-400 border-transparent hover:text-gray-300 hover:border-gray-600'
                  }`}
                >
                  <Icon className="w-4 h-4" />
                  <span>{tab.label}</span>
                </button>
              );
            })}
          </nav>
        </div>
      </div>

      {/* Main Content */}
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-8">
      {activeTab === 'new' && (
        <div className="flex items-center justify-center min-h-[80vh] px-4">
          <div className="bg-gray-800 border border-gray-700 rounded-2xl shadow-2xl p-8 max-w-xl w-full text-center transition-all duration-300 hover:shadow-blue-700/30">
            
            {/* Header with icon */}
            <div className="mb-6 flex flex-col items-center">
              <div className="bg-gradient-to-r from-blue-600 to-purple-600 p-3 rounded-full shadow-lg mb-4">
                <FilePlus className="w-6 h-6 text-white" />
              </div>
              <h2 className="text-3xl font-extrabold text-white mb-2">Submit a New Ticket</h2>
              <p className="text-gray-400 text-sm">Describe your IT issue using voice or text — we’ll take it from here!</p>
            </div>

            {/* Ticket form */}
            <TicketForm onTicketSubmit={handleTicketSubmit} />
          </div>
        </div>
      )}


        {activeTab === 'history' && (
          <div>
            <div className="mb-8 flex items-center justify-between">
              <div>
                <h2 className="text-2xl font-bold text-white mb-2">Ticket History</h2>
                <p className="text-gray-400">View and manage all your support tickets</p>
              </div>
              <button
                onClick={loadTickets}
                disabled={isLoadingTickets}
                className="flex items-center gap-2 px-4 py-2 bg-blue-600 hover:bg-blue-700 text-white rounded-lg transition-colors disabled:opacity-50"
              >
                {isLoadingTickets ? 'Loading...' : 'Refresh'}
              </button>
            </div>
            <TicketHistory 
              tickets={tickets} 
              onTicketUpdate={handleTicketUpdate}
            />
          </div>
        )}

        {activeTab === 'chat' && (
          <div>
            <div className="mb-8">
              <h2 className="text-2xl font-bold text-white mb-2">Live Chat Support</h2>
              <p className="text-gray-400">Get instant help from our AI assistant</p>
            </div>
            <ChatInterface onCreateTicket={handleCreateTicketFromChat} />
          </div>
        )}
      </div>

      {/* Confirmation Modal */}
      {showConfirmation && (
        <TicketConfirmation
          ticket={showConfirmation}
          onClose={() => setShowConfirmation(null)}
        />
      )}
    </div>
  );
}

export default App;