import React, { useEffect, useState } from 'react';
import { CheckCircle, Volume2, VolumeX, Copy, Check } from 'lucide-react';
import { Ticket } from '../types';
import { TextToSpeechService } from '../services/speechService';

interface TicketConfirmationProps {
  ticket: Ticket;
  onClose: () => void;
}

export const TicketConfirmation: React.FC<TicketConfirmationProps> = ({ ticket, onClose }) => {
  const [isSpeaking, setIsSpeaking] = useState(false);
  const [isCopied, setIsCopied] = useState(false);
  const [ttsService] = useState(() => new TextToSpeechService());

  const speechText = `Ticket submitted successfully. Ticket ID: ${ticket.id}. Department: ${ticket.department}. Team: ${ticket.sub_department}. Issue Type: ${ticket.issue_type}. Priority: ${ticket.urgency}. Summary: ${ticket.summary}.`;

  useEffect(() => {
    // Auto-play confirmation
    ttsService.speak(speechText);
    setIsSpeaking(true);
    
    const timer = setTimeout(() => {
      setIsSpeaking(false);
    }, 5000);

    return () => {
      clearTimeout(timer);
      ttsService.stop();
    };
  }, []);

  const toggleSpeech = () => {
    if (isSpeaking) {
      ttsService.stop();
      setIsSpeaking(false);
    } else {
      ttsService.speak(speechText);
      setIsSpeaking(true);
      setTimeout(() => setIsSpeaking(false), 5000);
    }
  };

  const copyTicketId = async () => {
    try {
      await navigator.clipboard.writeText(ticket.id);
      setIsCopied(true);
      setTimeout(() => setIsCopied(false), 2000);
    } catch (error) {
      console.error('Failed to copy ticket ID:', error);
    }
  };

  const getUrgencyColor = (urgency: string) => {
    switch (urgency) {
      case 'Low': return 'text-green-400 bg-green-400/10 border-green-400/20';
      case 'Medium': return 'text-yellow-400 bg-yellow-400/10 border-yellow-400/20';
      case 'High': return 'text-orange-400 bg-orange-400/10 border-orange-400/20';
      case 'Critical': return 'text-red-400 bg-red-400/10 border-red-400/20';
      default: return 'text-gray-400 bg-gray-400/10 border-gray-400/20';
    }
  };

  return (
    <div className="fixed inset-0 bg-black/50 flex items-center justify-center p-4 z-50">
      <div className="bg-gray-900 rounded-xl p-6 max-w-md w-full border border-gray-800 shadow-2xl">
        <div className="text-center mb-6">
          <div className="w-16 h-16 bg-green-600 rounded-full flex items-center justify-center mx-auto mb-4">
            <CheckCircle className="w-8 h-8 text-white" />
          </div>
          <h2 className="text-2xl font-bold text-white mb-2">Ticket Submitted!</h2>
          <p className="text-gray-400">Your support request has been received</p>
        </div>

        <div className="space-y-4 mb-6">
          <div className="bg-gray-800 rounded-lg p-4 border border-gray-700">
            <div className="flex items-center justify-between mb-2">
              <span className="text-sm text-gray-400">Ticket ID</span>
              <button
                onClick={copyTicketId}
                className="flex items-center gap-1 text-blue-400 hover:text-blue-300 transition-colors"
              >
                {isCopied ? (
                  <>
                    <Check className="w-4 h-4" />
                    <span className="text-xs">Copied</span>
                  </>
                ) : (
                  <>
                    <Copy className="w-4 h-4" />
                    <span className="text-xs">Copy</span>
                  </>
                )}
              </button>
            </div>
            <p className="text-white font-mono text-lg">{ticket.id}</p>
          </div>

          <div className="grid grid-cols-2 gap-4">
            <div className="bg-gray-800 rounded-lg p-3 border border-gray-700">
              <p className="text-xs text-gray-400 mb-1">Department</p>
              <p className="text-white font-medium">{ticket.department}</p>
            </div>
            <div className="bg-gray-800 rounded-lg p-3 border border-gray-700">
              <p className="text-xs text-gray-400 mb-1">Team</p>
              <p className="text-white font-medium">{ticket.sub_department}</p>
            </div>
          </div>

          <div className="bg-gray-800 rounded-lg p-3 border border-gray-700">
            <p className="text-xs text-gray-400 mb-1">Issue Type</p>
            <p className="text-white font-medium">{ticket.issue_type}</p>
          </div>

          <div className="flex items-center justify-between bg-gray-800 rounded-lg p-3 border border-gray-700">
            <div>
              <p className="text-xs text-gray-400 mb-1">Priority</p>
              <span className={`px-2 py-1 rounded-full text-xs font-medium border ${getUrgencyColor(ticket.urgency)}`}>
                {ticket.urgency}
              </span>
            </div>
          </div>

          <div className="bg-gray-800 rounded-lg p-3 border border-gray-700">
            <p className="text-xs text-gray-400 mb-1">Summary</p>
            <p className="text-white text-sm leading-relaxed">{ticket.summary}</p>
          </div>
        </div>

        <div className="flex gap-3">
          <button
            onClick={toggleSpeech}
            className={`flex items-center gap-2 px-4 py-2 rounded-lg transition-all duration-200 ${
              isSpeaking 
                ? 'bg-red-600 hover:bg-red-700 text-white' 
                : 'bg-blue-600 hover:bg-blue-700 text-white'
            }`}
          >
            {isSpeaking ? (
              <>
                <VolumeX className="w-4 h-4" />
                <span>Stop</span>
              </>
            ) : (
              <>
                <Volume2 className="w-4 h-4" />
                <span>Listen</span>
              </>
            )}
          </button>
          
          <button
            onClick={onClose}
            className="flex-1 px-4 py-2 bg-gray-700 hover:bg-gray-600 text-white rounded-lg transition-all duration-200"
          >
            Close
          </button>
        </div>
      </div>
    </div>
  );
};