import React, { useState } from 'react';
import { Send, User, Mail, FileText, Loader } from 'lucide-react';
import { VoiceRecorder } from './VoiceRecorder';
import { TextToSpeechService } from '../services/speechService';
import { apiService } from '../services/apiService';
import { Ticket } from '../types';

interface TicketFormProps {
  onTicketSubmit: (ticket: Ticket) => void;
}

export const TicketForm: React.FC<TicketFormProps> = ({ onTicketSubmit }) => {
  const [formData, setFormData] = useState({
    requester: '',
    email: '',
    content: ''
  });
  const [isSubmitting, setIsSubmitting] = useState(false);
  const [error, setError] = useState<string | null>(null);
  const [ttsService] = useState(() => new TextToSpeechService());

  const handleVoiceTranscript = (transcript: string) => {
    setFormData(prev => ({ ...prev, content: transcript }));
  };

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault();
    
    if (!formData.requester.trim() || !formData.email.trim() || !formData.content.trim()) {
      setError('Please fill in all required fields');
      return;
    }

    setIsSubmitting(true);
    setError(null);

    try {
      const ticket = await apiService.submitTicket({
        requester: formData.requester,
        email: formData.email,
        content: formData.content
      });

      // Convert backend response to frontend Ticket format
      const formattedTicket: Ticket = {
        ...ticket,
        status: 'Open' as const,
        timestamp: new Date(ticket.timestamp).toLocaleString()
      };

      onTicketSubmit(formattedTicket);

      // Text-to-speech confirmation
      const speechText = `Ticket submitted successfully. Ticket ID: ${ticket.id}. Department: ${ticket.department}. Priority: ${ticket.urgency}.`;
      ttsService.speak(speechText);

      // Reset form
      setFormData({ requester: '', email: '', content: '' });
    } catch (error) {
      console.error('Error submitting ticket:', error);
      setError(error instanceof Error ? error.message : 'Failed to submit ticket. Please try again.');
    } finally {
      setIsSubmitting(false);
    }
  };

  return (
    <div className="max-w-2xl mx-auto">
      <div className="bg-gray-900 rounded-xl p-6 shadow-2xl border border-gray-800">
        <div className="flex items-center gap-3 mb-6">
 
        </div>

        {error && (
          <div className="mb-6 p-4 bg-red-900/50 border border-red-700 rounded-lg">
            <p className="text-red-300 text-sm">{error}</p>
          </div>
        )}

        <form onSubmit={handleSubmit} className="space-y-6">
          <div className="grid grid-cols-1 md:grid-cols-2 gap-4">
            <div>
              <label className="block text-sm font-medium text-gray-300 mb-2 text-left">
                <User className="w-4 h-4 inline mr-2" />
                Your Name
              </label>
              <input
                type="text"
                value={formData.requester}
                onChange={(e) => setFormData(prev => ({ ...prev, requester: e.target.value }))}
                className="w-full px-4 py-3 bg-gray-800 border border-gray-700 rounded-lg text-white placeholder-gray-500 focus:outline-none focus:ring-2 focus:ring-blue-500 focus:border-transparent transition-all duration-200"
                placeholder="Enter your full name"
                required
                disabled={isSubmitting}
              />
            </div>

            <div>
              <label className="block text-sm font-medium text-gray-300 mb-2 text-left flex items-center gap-2">
                <Mail className="w-4 h-4 text-gray-400" />
                Email Address
              </label>

              <input
                type="email"
                value={formData.email}
                onChange={(e) => setFormData(prev => ({ ...prev, email: e.target.value }))}
                className="w-full px-4 py-3 bg-gray-800 border border-gray-700 rounded-lg text-white placeholder-gray-500 focus:outline-none focus:ring-2 focus:ring-blue-500 focus:border-transparent transition-all duration-200"
                placeholder="your.email@company.com"
                required
                disabled={isSubmitting}
              />
            </div>
          </div>

          <div>
            <label className="block text-sm font-medium text-gray-300 mb-3">
              Describe Your Issue
            </label>
            
            <VoiceRecorder 
              onTranscript={handleVoiceTranscript}
              disabled={isSubmitting}
            />
            
            <div className="mt-4">
              <textarea
                value={formData.content}
                onChange={(e) => setFormData(prev => ({ ...prev, content: e.target.value }))}
                rows={6}
                className="w-full px-4 py-3 bg-gray-800 border border-gray-700 rounded-lg text-white placeholder-gray-500 focus:outline-none focus:ring-2 focus:ring-blue-500 focus:border-transparent transition-all duration-200 resize-none"
                placeholder="Type your issue description here or use voice recording above..."
                required
                disabled={isSubmitting}
              />
            </div>
          </div>

          <button
            type="submit"
            disabled={isSubmitting || !formData.requester.trim() || !formData.email.trim() || !formData.content.trim()}
            className="w-full flex items-center justify-center gap-3 px-6 py-4 bg-gradient-to-r from-blue-600 to-purple-600 hover:from-blue-700 hover:to-purple-700 text-white font-medium rounded-lg transition-all duration-200 hover:scale-105 disabled:opacity-50 disabled:cursor-not-allowed disabled:hover:scale-100 shadow-lg shadow-blue-600/25"
          >
            {isSubmitting ? (
              <>
                <Loader className="w-5 h-5 animate-spin" />
                <span>Processing Ticket...</span>
              </>
            ) : (
              <>
                <Send className="w-5 h-5" />
                <span>Submit Ticket</span>
              </>
            )}
          </button>
        </form>
      </div>
    </div>
  );
};