import React, { useState, useEffect } from 'react';
import { Mic, MicOff, Volume2 } from 'lucide-react';
import { SpeechService } from '../services/speechService';

interface VoiceRecorderProps {
  onTranscript: (transcript: string) => void;
  disabled?: boolean;
}

export const VoiceRecorder: React.FC<VoiceRecorderProps> = ({ onTranscript, disabled = false }) => {
  const [isListening, setIsListening] = useState(false);
  const [transcript, setTranscript] = useState('');
  const [isSupported, setIsSupported] = useState(false);
  const [speechService] = useState(() => new SpeechService());

  useEffect(() => {
    setIsSupported(speechService.isSupported());
  }, [speechService]);

  const startListening = () => {
    if (!isSupported || disabled) return;

    speechService.startListening(
      (result) => {
        setTranscript(result.transcript);
        if (result.isFinal) {
          onTranscript(result.transcript);
        }
      },
      (error) => {
        console.error('Speech recognition error:', error);
        setIsListening(false);
      }
    );
    setIsListening(true);
  };

  const stopListening = () => {
    speechService.stopListening();
    setIsListening(false);
    if (transcript) {
      onTranscript(transcript);
    }
  };

  const toggleListening = () => {
    if (isListening) {
      stopListening();
    } else {
      startListening();
    }
  };

  if (!isSupported) {
    return (
      <div className="flex items-center justify-center p-4 bg-gray-800 rounded-lg border border-gray-700">
        <MicOff className="w-5 h-5 text-gray-500 mr-2" />
        <span className="text-gray-400 text-sm">Speech recognition not supported in this browser</span>
      </div>
    );
  }

  return (
    <div className="space-y-3">
      <button
        onClick={toggleListening}
        disabled={disabled}
        className={`
          w-full flex items-center justify-center gap-3 px-6 py-4 rounded-lg font-medium transition-all duration-200
          ${isListening 
            ? 'bg-red-600 hover:bg-red-700 text-white shadow-lg shadow-red-600/25' 
            : 'bg-blue-600 hover:bg-blue-700 text-white shadow-lg shadow-blue-600/25'
          }
          ${disabled ? 'opacity-50 cursor-not-allowed' : 'hover:scale-105'}
        `}
      >
        {isListening ? (
          <>
            <div className="w-2 h-2 bg-white rounded-full animate-pulse"></div>
            <MicOff className="w-5 h-5" />
            <span>Stop Recording</span>
          </>
        ) : (
          <>
            <Mic className="w-5 h-5" />
            <span>Start Voice Recording</span>
            <Volume2 className="w-4 h-4 opacity-70" />
          </>
        )}
      </button>

      {isListening && (
        <div className="bg-gray-800 rounded-lg p-4 border border-gray-700">
          <div className="flex items-center gap-2 mb-2">
            <div className="flex gap-1">
              <div className="w-2 h-2 bg-red-500 rounded-full animate-pulse"></div>
              <div className="w-2 h-2 bg-red-500 rounded-full animate-pulse" style={{ animationDelay: '0.1s' }}></div>
              <div className="w-2 h-2 bg-red-500 rounded-full animate-pulse" style={{ animationDelay: '0.2s' }}></div>
            </div>
            <span className="text-red-400 text-sm font-medium">Listening...</span>
          </div>
          <div className="text-gray-300 text-sm min-h-[1.5rem]">
            {transcript || 'Speak now...'}
          </div>
        </div>
      )}
    </div>
  );
};